pub struct TaskQueue;Expand description
A task queue that delegates to a backend for task storage and retrieval.
Implementations
Sourceimpl TaskQueue
impl TaskQueue
Sourcepub fn with_config(_config: QueueConfig) -> Self
pub fn with_config(_config: QueueConfig) -> Self
Creates a new task queue with the given configuration.
Sourcepub async fn enqueue(
&self,
task: Box<dyn Task>,
backend: &dyn TaskBackend,
) -> Result<TaskId, TaskExecutionError>
pub async fn enqueue( &self, task: Box<dyn Task>, backend: &dyn TaskBackend, ) -> Result<TaskId, TaskExecutionError>
Enqueues a task for execution through the specified backend.